@@ -18,9 +18,11 @@ CURSES_ESCDELAY = '50'
 def _init(stdscr):
     if not hasattr(stdscr, 'get_wch'):
         raise RuntimeError(
-'''Wide characters are not supported by curses module. Please install 
-ncursesw package and rebuild Python.
-See https://pypi.python.org/pypi/kaaedit/#requirements for detail.''')
+'''Wide characters are not supported by curses module. 
+Please install development package for ncursesw library and rebuild Python.
+
+See https://pypi.python.org/pypi/kaaedit/#requirements for detail.
+''')
 
     curses.start_color()
     curses.use_default_colors()
@@ -73,7 +75,7 @@ def main(stdscr):
 
         if not opt.file:
             # no file args. show new document.
-            doc = fileio.newfile(provisional=True)
+            doc = kaa.app.storage.newfile(temporary=True)
             kaa.app.show_doc(doc)
         else:
             dirname = None
@@ -95,7 +97,7 @@ def main(stdscr):
                         kaa.app.show_doc(doc)
                     else:
                         if not kaa.app.mainframe.childframes:
-                            doc = fileio.newfile(provisional=True)
+                            doc = kaa.app.storage.newfile(temporary=True)
                             kaa.app.show_doc(doc)
 
                 selectfile.show_fileopen(dirname, cb)
