@@ -77,7 +77,7 @@ class PasteLinesMode(dialogmode.DialogMode):
         f, t = self.document.marks['pastetext']
         s = self.document.gettext(f, t)
 
-        self.target.document.mode.edit_commands.put_string(self.target, s)
+        self.target.document.mode.put_string(self.target, s)
         w.screen.selection.clear()
 
         kaa.app.messagebar.set_message("{} letters inserted".format(t - f))
