@@ -1,4 +1,6 @@
-import os, functools
+import kaa
+import os
+import functools
 
 
 def ignore_errors(f):
@@ -9,11 +11,13 @@ def ignore_errors(f):
         except Exception:
             try:
                 kaa.log.exception('')
-            except Exception:
+            except Exception as e:
                 # Ignore error completely...
                 pass
+
     return wrapper
-    
+
+
 def split_existing_dirs(path):
     path, p = os.path.split(path)
     rights = [p]
